variable "cloudwatch_schedule" {
  description = "Schedule for cloudwatch event to invoke Lambda function"
  default = "rate(2 hours)"
}

resource "aws_iam_role" "packer_janitor" {
    name = "iam_packer_janitor"
    assume_role_policy = "${file("${path.module}/assume-role.json")}"
}

resource "aws_iam_policy" "packer_janitor" {
    name = "packer_janitor"
    policy = "${file("${path.module}/iam-policy.json")}"
}

resource "aws_iam_role_policy_attachment" "packer_janitor" {
    role = "${aws_iam_role.packer_janitor.name}"
    policy_arn = "${aws_iam_policy.packer_janitor.arn}"
}

resource "aws_lambda_function" "packer_janitor" {
    filename = "${path.module}/packer_janitor.zip"
    function_name = "packer_janitor"
    role = "${aws_iam_role.packer_janitor.arn}"
    handler = "packer_janitor.lambda_handler"
    timeout = "300"
    runtime = "python2.7"
    source_code_hash = "${base64sha256(file("${path.module}/packer_janitor.zip"))}"
}

resource "aws_cloudwatch_event_rule" "packer_janitor" {
  name = "packer_janitor"
  description = "Run packer janitor to tidy up stale packer instances."
  schedule_expression = "${var.cloudwatch_schedule}"
}

resource "aws_cloudwatch_event_target" "packer_janitor" {
    rule = "${aws_cloudwatch_event_rule.packer_janitor.name}"
    arn = "${aws_lambda_function.packer_janitor.arn}"
}

resource "aws_lambda_permission" "allow_cloudwatch" {
    statement_id = "AllowExecutionFromCloudWatch"
    action = "lambda:InvokeFunction"
    function_name = "${aws_lambda_function.packer_janitor.arn}"
    principal = "events.amazonaws.com"
}